@@ -55,23 +55,39 @@ from configparser import ConfigParser
 def pytest_sessionfinish(session):
     """在整个测试运行完成之后调用的钩子函数,可以在此处生成测试报告"""
     report2 = session.config.getoption('--report')
-    conf = ConfigParser()
-    name = 'report.html'
-    if session.config.inifile:
-        conf.read(session.config.inifile)
-    if 'report' in conf.sections():
-        if 'title' in conf.options('report'):
-            test_result['title'] = conf.get('report', 'title') or '测试报告'
-        if 'tester' in conf.options('report'):
-            test_result['tester'] = conf.get('report', 'tester') or '小测试'
-        if 'desc' in conf.options('report'):
-            test_result['desc'] = conf.get('report', 'desc') or '无'
-        if 'file_name' in conf.options('report'):
-            name = conf.get('report', 'file_name')
-    elif report2:
-        test_result['title'] = '测试报告'
-        test_result['tester'] = '小测试'
-        test_result['desc'] = '无'
+    # -----------------配置文件的支持------------------------------
+    # conf = ConfigParser()
+    # name = 'report.html'
+    # if session.config.inifile:
+    #     conf.read(session.config.inifile,encoding='utf-8')
+    # if 'report' in conf.sections():
+    #     if 'title' in conf.options('report'):
+    #         test_result['title'] = conf.get('report', 'title')
+    #     else:
+    #         test_result['title'] = '测试报告'
+    #     if 'tester' in conf.options('report'):
+    #         test_result['tester'] = conf.get('report', 'tester')
+    #     else:
+    #         test_result['tester'] = '测试员'
+    #     if 'desc' in conf.options('report'):
+    #         test_result['desc'] = conf.get('report', 'desc')
+    #     else:
+    #         test_result['tester'] = '无'
+    #     if 'file_name' in conf.options('report'):
+    #         name = conf.get('report', 'file_name')
+    # elif report2:
+    #     test_result['title'] = session.config.getoption('--title') or '测试报告'
+    #     test_result['tester'] = session.config.getoption('--tester') or '小测试'
+    #     test_result['desc'] = session.config.getoption('--desc') or '无'
+    #     name = report2
+    # else:
+    #     return
+    # -----------------配置文件的支持------------------------------
+
+    if report2:
+        test_result['title'] = session.config.getoption('--title') or '测试报告'
+        test_result['tester'] = session.config.getoption('--tester') or '小测试'
+        test_result['desc'] = session.config.getoption('--desc') or '无'
         name = report2
     else:
         return
@@ -124,3 +140,24 @@ def pytest_addoption(parser):
         default=None,
         help="create html report file at given path.",
     )
+    group.addoption(
+        "--title",
+        action="store",
+        metavar="path",
+        default=None,
+        help="pytest-testreport Generate a title of the repor",
+    )
+    group.addoption(
+        "--tester",
+        action="store",
+        metavar="path",
+        default=None,
+        help="pytest-testreport Generate a tester of the report",
+    )
+    group.addoption(
+        "--desc",
+        action="store",
+        metavar="path",
+        default=None,
+        help="pytest-testreport Generate a description of the report",
+    )
\ No newline at end of file
